NormalLayer

Struct NormalLayer 

pub struct NormalLayer<'a> {
    layer: &'a LayerRecord,
    layer_idx: usize,
    psd: &'a PsdReader,
}
Available on crate feature utils-psd only.

Fields

layer: &'a LayerRecordlayer_idx: usizepsd: &'a PsdReader

Implementations

Source

impl<'a> NormalLayer<'a>

pub fn layer_name(&self) -> Result<String>

Returns the name of the layer.

pub fn layer_index(&self) -> usize

Returns the current layer’s index in the PSD file.

pub fn top(&self) -> i32

Returns the top position of the layer.

pub fn left(&self) -> i32

Returns the left position of the layer.

pub fn bottom(&self) -> i32

Returns the bottom position of the layer.

pub fn right(&self) -> i32

Returns the right position of the layer.

pub fn width(&self) -> u32

Returns the width of the layer.

pub fn height(&self) -> u32

Returns the height of the layer.

pub fn channels(&self) -> u16

Returns the number of channels in the layer.

pub fn read_raw_data(&self) -> Result<Vec<(i16, Vec<u8>)>>

Reads and returns the raw channel id and data of the layer.

pub fn image(&self) -> Result<ImageData>

Reads and returns the image data of the layer.