PsdWriter

Struct PsdWriter 

pub struct PsdWriter {
    psd: PsdFile,
    color_type: ImageColorType,
    compress: bool,
    zlib_compression_level: u32,
    encoding: Encoding,
}
Available on crate feature utils-psd only.
A simple PSD writer.

Fields

psd: PsdFilecolor_type: ImageColorTypecompress: boolzlib_compression_level: u32encoding: Encoding

Implementations

Source

impl PsdWriter

pub fn new( width: u32, height: u32, color_type: ImageColorType, depth: u8, encoding: Encoding, ) -> Result<Self>

Creates a new PSD writer with the specified dimensions, color type, and bit depth.

pub fn compress(self, compress: bool) -> Self

Sets whether to compress image data in the PSD file.

pub fn zlib_compression_level(self, level: u32) -> Self

Sets the zlib compression level for the PSD file.

pub fn add_layer( &mut self, name: &str, x: u32, y: u32, data: ImageData, option: Option<PsdLayerOption>, ) -> Result<()>

Add a layer to the PSD file.

  • name - The name of the layer.
  • x - The x position of the layer.
  • y - The y position of the layer.
  • data - The image data of the layer.
  • option - The options for the layer.
pub fn add_layer_group( &mut self, name: &str, is_closed: bool, option: Option<PsdLayerOption>, ) -> Result<()>

Adds the start of a layer group to the PSD file.

pub fn add_layer_group_end(&mut self) -> Result<()>

Adds the end of a layer group to the PSD file.

pub fn save<T: Write>(&mut self, data: ImageData, writer: T) -> Result<()>

Saves the PSD file to the specified writer with the given encoding.

  • data - The final composite image data to be saved in the PSD file.